==> huaweicloudsdkhss-3.1.99-py2.py3-none-any.whl: huaweicloudsdkhss/v5/model/vulnerability_host_number_info.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class VulnerabilityHostNumberInfo:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'important': 'int',
        'common': 'int',
        'test': 'int'
    }

    attribute_map = {
        'important': 'important',
        'common': 'common',
        'test': 'test'
    }

    def __init__(self, important=None, common=None, test=None):
        """VulnerabilityHostNumberInfo

        The model defined in huaweicloud sdk

        :param important: 重要主机数量
        :type important: int
        :param common: 一般主机数量
        :type common: int
        :param test: 测试主机数量
        :type test: int
        """
        
        

        self._important = None
        self._common = None
        self._test = None
        self.discriminator = None

        if important is not None:
            self.important = important
        if common is not None:
            self.common = common
        if test is not None:
            self.test = test

    @property
    def important(self):
        """Gets the important of this VulnerabilityHostNumberInfo.

        重要主机数量

        :return: The important of this VulnerabilityHostNumberInfo.
        :rtype: int
        """
        return self._important

    @important.setter
    def important(self, important):
        """Sets the important of this VulnerabilityHostNumberInfo.

        重要主机数量

        :param important: The important of this VulnerabilityHostNumberInfo.
        :type important: int
        """
        self._important = important

    @property
    def common(self):
        """Gets the common of this VulnerabilityHostNumberInfo.

        一般主机数量

        :return: The common of this VulnerabilityHostNumberInfo.
        :rtype: int
        """
        return self._common

    @common.setter
    def common(self, common):
        """Sets the common of this VulnerabilityHostNumberInfo.

        一般主机数量

        :param common: The common of this VulnerabilityHostNumberInfo.
        :type common: int
        """
        self._common = common

    @property
    def test(self):
        """Gets the test of this VulnerabilityHostNumberInfo.

        测试主机数量

        :return: The test of this VulnerabilityHostNumberInfo.
        :rtype: int
        """
        return self._test

    @test.setter
    def test(self, test):
        """Sets the test of this VulnerabilityHostNumberInfo.

        测试主机数量

        :param test: The test of this VulnerabilityHostNumberInfo.
        :type test: int
        """
        self._test = test

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, VulnerabilityHostNumberInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkhss-3.1.146-py2.py3-none-any.whl: huaweicloudsdkhss/v5/model/vulnerability_host_number_info.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class VulnerabilityHostNumberInfo:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'important': 'int',
        'common': 'int',
        'test': 'int'
    }

    attribute_map = {
        'important': 'important',
        'common': 'common',
        'test': 'test'
    }

    def __init__(self, important=None, common=None, test=None):
        r"""VulnerabilityHostNumberInfo

        The model defined in huaweicloud sdk

        :param important: 重要主机数量
        :type important: int
        :param common: 一般主机数量
        :type common: int
        :param test: 测试主机数量
        :type test: int
        """
        
        

        self._important = None
        self._common = None
        self._test = None
        self.discriminator = None

        if important is not None:
            self.important = important
        if common is not None:
            self.common = common
        if test is not None:
            self.test = test

    @property
    def important(self):
        r"""Gets the important of this VulnerabilityHostNumberInfo.

        重要主机数量

        :return: The important of this VulnerabilityHostNumberInfo.
        :rtype: int
        """
        return self._important

    @important.setter
    def important(self, important):
        r"""Sets the important of this VulnerabilityHostNumberInfo.

        重要主机数量

        :param important: The important of this VulnerabilityHostNumberInfo.
        :type important: int
        """
        self._important = important

    @property
    def common(self):
        r"""Gets the common of this VulnerabilityHostNumberInfo.

        一般主机数量

        :return: The common of this VulnerabilityHostNumberInfo.
        :rtype: int
        """
        return self._common

    @common.setter
    def common(self, common):
        r"""Sets the common of this VulnerabilityHostNumberInfo.

        一般主机数量

        :param common: The common of this VulnerabilityHostNumberInfo.
        :type common: int
        """
        self._common = common

    @property
    def test(self):
        r"""Gets the test of this VulnerabilityHostNumberInfo.

        测试主机数量

        :return: The test of this VulnerabilityHostNumberInfo.
        :rtype: int
        """
        return self._test

    @test.setter
    def test(self, test):
        r"""Sets the test of this VulnerabilityHostNumberInfo.

        测试主机数量

        :param test: The test of this VulnerabilityHostNumberInfo.
        :type test: int
        """
        self._test = test

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, VulnerabilityHostNumberInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
